/* 
  CESYS Software License - Version 1.0 - January 1st, 2016

  Permission is hereby granted, free of charge, to any person or organization
  obtaining a copy of the software and accompanying documentation covered by
  this license (the "Software") to use, reproduce, display, distribute,
  execute, and transmit the Software, and to prepare derivative works of the
  Software, and to permit third-parties to whom the Software is furnished to
  do so, all subject to the following:

  The software must only be used to operate hardware manufactured by 
  CESYS GmbH, Herzogenaurach.

  The copyright notices in the Software and this entire statement, including
  the above license grant, this restriction and the following disclaimer,
  must be included in all copies of the Software, in whole or in part, and
  all derivative works of the Software, unless such copies or derivative
  works are solely in the form of machine-executable object code generated by
  a source language processor.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
  SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
  FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
  
  Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
*/

package com.cesys.cebomsr;

import com.cesys.utils.Loader;

import java.io.IOException;

/**
 * Offers functionality for current sources. Instances can be retrieved using
 * getCurrentSources() of the respective {@link Device} instance.
 *
 * @author Thomas Hoppe
 */
public final class CurrentSource {
	private final Device _device;
	private final int _interfaceId;
	private final String _name;

	int getInterfaceId() {
		return _interfaceId;
	}

	CurrentSource(Device device, int interfaceId, int index) throws IOException {
		_device = device;
		_interfaceId = interfaceId;
		byte[] tmp = new byte[SystemConnector.MaxIdentLength];
		Loader.checkError(SystemConnector.CeboMsrGetPeripheralName(device.getHandle(), interfaceId, tmp, SystemConnector.MaxIdentLength));
		_name = Utils.convertByteArrayToString(tmp);
	}

	/**
	 * Returns the real current of the constant current source in micro ampere.
	 */
	public float getReferenceCurrent() throws IOException {
		float[] r = new float[1];
		Loader.checkError(SystemConnector.CeboMsrGetReferenceCurrent(_device.getHandle(), getInterfaceId(), r));
		return r[0];
	}

	/**
	 * Returns name of the component.
	 */
	public String getName() {
		return _name;
	}

	@Override
	public String toString() {
		return "CurrentSource: " + _name;
	}
}
